% [gm,e] = gm_EM(X,K[,maxit]) Gaussian mixture EM clustering
%
% In:
%   X: NxD matrix containing N D-dimensional data points rowwise.
%   K: desired number of clusters.
%   maxit: maximum number of iterations. Default: 10.
% Out:
%   gm: Gaussian mixture struct. See GMpdf.m.
%   e: list of negative log-likelihood values.

function [gm,e] = gm_EM(X,K,maxit)

